@@ -43,6 +43,7 @@ class PhishingTriageClient(object):
                                     and 'IGNORED'. (default: ['UNRESOLVED']).
         :param string cursor: A Base64-encoded string that contains information on how to retrieve the next page.
                               If a cursor isn't passed, it will default to pageSize: 25, pageNumber: 0
+        :return: CursorPage.generator - A generator object which can be used to paginate through |PhishingSubmission| data.
         """
 
         phishing_submissions_page_generator = self._get_phishing_submissions_page_generator(
@@ -97,6 +98,7 @@ class PhishingTriageClient(object):
                                     and 'IGNORED'. (default: ['UNRESOLVED']).
         :param string cursor: A Base64-encoded string that contains information on how to retrieve the next page.
                               If a cursor isn't passed, it will default to pageSize: 25, pageNumber: 0
+        :return: |CursorPage| - An object representing a single page of |PhishingSubmission| objects.
         """
 
         data = self.remove_nones({
@@ -118,7 +120,6 @@ class PhishingTriageClient(object):
 
         :param string submission_id: ID of the email submission.
         :param string status: Triage status of submission.
-        :return:
         """
 
         if submission_id is None or not isinstance(submission_id, str):
@@ -145,6 +146,7 @@ class PhishingTriageClient(object):
                                     and 'IGNORED'. (default: ['UNRESOLVED']).
         :param string cursor: A Base64-encoded string that contains information on how to retrieve the next page.
                               If a cursor isn't passed, it will default to pageSize: 25, pageNumber: 0
+        :return: CursorPage.generator - A generator object which can be used to paginate through |PhishingIndicator| data.
         """
 
         phishing_indicators_page_generator = self._get_phishing_indicators_page_generator(
@@ -206,6 +208,7 @@ class PhishingTriageClient(object):
                                     and 'IGNORED'. (default: ['UNRESOLVED']).
         :param string cursor: A Base64-encoded string that contains information on how to retrieve the next page.
                               If a cursor isn't passed, it will default to pageSize: 25, pageNumber: 0
+        :return: |CursorPage| - An object representing a single page of |PhishingIndicator| objects.
         """
 
         data = self.remove_nones({
